==> kdebugsettings-debuginfo-17.04.3-1.tar.xz: usr/src/debug/kdebugsettings-17.04.3-1/src/kdeapplicationdebugsettingpage.h <==
/*
  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

*/

#ifndef KDEAPPLICATIONDEBUGSETTINGPAGE_H
#define KDEAPPLICATIONDEBUGSETTINGPAGE_H

#include <QWidget>
#include "loggingcategory.h"
class QPushButton;
class KDEApplicationTreeListWidget;
class KTreeWidgetSearchLine;
class KDEApplicationDebugSettingPage : public QWidget
{
    Q_OBJECT
public:
    explicit KDEApplicationDebugSettingPage(QWidget *parent = nullptr);
    ~KDEApplicationDebugSettingPage();
    void fillList(const LoggingCategory::List &list);
    LoggingCategory::List rules() const;
    void insertCategories(const LoggingCategory::List &list);
protected:
    bool eventFilter(QObject *obj, QEvent *event) Q_DECL_OVERRIDE;

private Q_SLOTS:
    void slotSelectAll();
    void slotDeselectAll();
private:
    KDEApplicationTreeListWidget *mTreeListWidget;
    KTreeWidgetSearchLine *mTreeListWidgetSearchLine;
    QPushButton *mEnableDebug;
    QPushButton *mTurnOffDebug;
};

#endif // KDEAPPLICATIONDEBUGSETTINGPAGE_H

==> kdebugsettings-debuginfo-17.08.3-1.tar.xz: usr/src/debug/kdebugsettings-17.08.3-1/src/kdeapplicationdebugsettingpage.h <==
/*
  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

*/

#ifndef KDEAPPLICATIONDEBUGSETTINGPAGE_H
#define KDEAPPLICATIONDEBUGSETTINGPAGE_H

#include <QWidget>
#include "loggingcategory.h"
class QPushButton;
class KDEApplicationTreeListWidget;
class KTreeWidgetSearchLine;
class KDEApplicationDebugSettingPage : public QWidget
{
    Q_OBJECT
public:
    explicit KDEApplicationDebugSettingPage(QWidget *parent = nullptr);
    ~KDEApplicationDebugSettingPage();
    void fillList(const LoggingCategory::List &list);
    LoggingCategory::List rules() const;
    void insertCategories(const LoggingCategory::List &list);
protected:
    bool eventFilter(QObject *obj, QEvent *event) override;

private Q_SLOTS:
    void slotSelectAll();
    void slotDeselectAll();
private:
    KDEApplicationTreeListWidget *mTreeListWidget;
    KTreeWidgetSearchLine *mTreeListWidgetSearchLine;
    QPushButton *mEnableDebug;
    QPushButton *mTurnOffDebug;
};

#endif // KDEAPPLICATIONDEBUGSETTINGPAGE_H
